@@ -1,5 +1,5 @@
 cost2 <-
-function(x, data_x, data_y, prior_st = 1)
+function(x, data_x, data_y, prior_st)
 {
 dm = dim(data_x)[2]
 data_num = dim(data_x)[1]
